@@ -160,8 +160,10 @@ class TestAsyncClient(unittest.TestCase):
     def test_disconnect_not_connected(self):
         c = asyncio_client.AsyncClient()
         c.state = 'foo'
+        c.sid = 'bar'
         _run(c.disconnect())
         self.assertEqual(c.state, 'disconnected')
+        self.assertIsNone(c.sid)
 
     def test_disconnect_polling(self):
         c = asyncio_client.AsyncClient()
@@ -1054,7 +1056,7 @@ class TestAsyncClient(unittest.TestCase):
         c._send_request.mock.assert_called_once_with(
             'POST', 'http://foo', body=p.encode(),
             headers={'Content-Type': 'application/octet-stream'})
-        self.assertEqual(c.state, 'disconnected')
+        self.assertEqual(c.state, 'connected')
 
     def test_write_loop_polling_bad_status(self):
         c = asyncio_client.AsyncClient()
@@ -1150,4 +1152,4 @@ class TestAsyncClient(unittest.TestCase):
         c.ws.send = AsyncMock(
             side_effect=websockets.exceptions.ConnectionClosed(1, 'foo'))
         _run(c._write_loop())
-        self.assertEqual(c.state, 'disconnected')
+        self.assertEqual(c.state, 'connected')
